@@ -352,9 +352,9 @@ class Spectrum:
         self.values = white_tophat(self.values, disk(size))
         return self
 
-    def sub_first_row(self):
+    def sub_first_rows(self, n=1):
         """
-        Subtracts first row from every row in spectrum.
+        Subtracts first n rows from every row in spectrum.
         Effective and simple baseline correction
         if RIP tailing is a concern but can hide small peaks.
 
@@ -362,9 +362,9 @@ class Spectrum:
         -------
         Spectrum
         """
-        fl = self.values[0, :]
+        fl = self.values[0:n-1, :].mean(axis=0)
         self.values = self.values - fl
-        self.values[self.values < 0] = 0
+        # self.values[self.values < 0] = 0
         return self
 
     def riprel(self):
@@ -392,7 +392,7 @@ class Spectrum:
         """
         Scales values relative to global maximum.
         Can be useful to directly compare spectra from
-        instruments with different sensitivity. 
+        instruments with different sensitivity.
 
         Returns
         -------
@@ -403,7 +403,7 @@ class Spectrum:
         self.values = self.values / m
         return self
 
-    def resample(self, n):
+    def resample(self, n=2):
         """
         Resamples spectrum by calculating means of every n rows.
         If the length of the retention time is not divisible by n
@@ -411,14 +411,15 @@ class Spectrum:
 
         Parameters
         ----------
-        n : int
-            Number of rows to mean.
+        n : int, optional
+            Number of rows to mean,
+            by default 2.
 
         Returns
         -------
         Spectrum
             Resampled values.
-            
+
         Example
         -------
         >>> import ims
@@ -439,7 +440,7 @@ class Spectrum:
         self.ret_time = self.ret_time[::n]
         return self
 
-    def binning(self, n):
+    def binning(self, n=2):
         """
         Downsamples spectrum by binning the array with factor n.
         Similar to ims.Spectrum.resampling but works on both dimensions
@@ -451,8 +452,8 @@ class Spectrum:
 
         Parameters
         ----------
-        n : int
-            Binning factor.
+        n : int, optional
+            Binning factor, by default 2.
 
         Returns
         -------
